@@ -29,7 +29,7 @@
     <message>
         <location filename="../ui/dialogsettings.ui" line="24"/>
         <source>Interface</source>
-        <translation type="unfinished"></translation>
+        <translation>Вид</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="64"/>
@@ -64,22 +64,22 @@
     <message>
         <location filename="../ui/dialogsettings.ui" line="149"/>
         <source>Language</source>
-        <translation type="unfinished"></translation>
+        <translation>Язык</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="179"/>
         <source>Always enable preview zooming</source>
-        <translation type="unfinished"></translation>
+        <translation>Всегда разрешать масштабирование предпросмотра</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="186"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Внимание: предпросмотр может быть неточным&lt;br/&gt;если включено.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="215"/>
         <source>Other</source>
-        <translation type="unfinished"></translation>
+        <translation>Другое</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="253"/>
@@ -104,17 +104,17 @@
     <message>
         <location filename="../ui/dialogsettings.ui" line="169"/>
         <source>Timeout (seconds)</source>
-        <translation type="unfinished"></translation>
+        <translation>Тайм-аут (в секундах)</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="36"/>
         <source>Show institution logos</source>
-        <translation type="unfinished"></translation>
+        <translation>Отображение институциональных логотипов</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="262"/>
         <source>Notify when scheduled update fails</source>
-        <translation type="unfinished"></translation>
+        <translation>Уведомлять в случае неудачи запланированного обновления</translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="304"/>
@@ -249,53 +249,81 @@
         <source>Error parsing filter parameters
 
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Ошибка при анализе параметров фильтра
+
+</translation>
     </message>
 </context>
 <context>
     <name>GmicQt::FiltersPresenter</name>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="477"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="498"/>
         <source>Unknown filter</source>
-        <translation type="unfinished"></translation>
+        <translation>Неизвестный фильтр</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="574"/>
-        <source>Cannot find this fave&apos;s original filter
-</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="606"/>
+        <source>Cannot find this fave&apos;s original filter</source>
+        <translation>Не удаётся найти оригинал этого избранного фильтра</translation>
     </message>
 </context>
 <context>
     <name>GmicQt::FiltersView</name>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="68"/>
-        <source>Rename fave</source>
-        <translation>Переименовать избранный</translation>
-    </message>
-    <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="70"/>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="347"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="350"/>
         <source>Remove fave</source>
         <translation>Удалить из избранного</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="72"/>
-        <source>Clone fave</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="670"/>
+        <source>Rename Fave</source>
+        <translation>Переименовать избранное</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="76"/>
-        <source>Add fave</source>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="672"/>
+        <source>Remove Fave</source>
+        <translation>Удалить из избранного</translation>
+    </message>
+    <message>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="674"/>
+        <source>Clone Fave</source>
+        <translation>Клонировать избранное</translation>
+    </message>
+    <message>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="678"/>
+        <source>Add Fave</source>
         <translation>Добавить в избранное</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="348"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="697"/>
+        <source>Remove All</source>
+        <translation>Удалить все</translation>
+    </message>
+    <message>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="704"/>
+        <source>%1 (%2 %3)</source>
+        <translation>%1 (%2 %3)</translation>
+    </message>
+    <message>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="704"/>
+        <source>Filters</source>
+        <translation>Фильтры</translation>
+    </message>
+    <message>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="704"/>
+        <source>Filter</source>
+        <translation>Фильтр</translation>
+    </message>
+    <message>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="351"/>
         <source>Do you really want to remove the following fave?
 
 %1
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Вы действительно хотите удалить этот фильтр из избранного?
+
+%1
+</translation>
     </message>
 </context>
 <context>
@@ -311,13 +339,14 @@
     <message>
         <location filename="../src/GmicProcessor.cpp" line="299"/>
         <source>Image #%1 returned by filter has %2 channels (should be at most 4)</source>
-        <translation type="unfinished"></translation>
+        <translation>Возвращённое фильтром изображение #%1 имеет %2 канал(а/ов) (должно быть не более 4)</translation>
     </message>
     <message>
         <location filename="../src/GmicProcessor.cpp" line="333"/>
         <source>Image #%1 returned by filter has %2 channels
 (should be at most 4)</source>
-        <translation type="unfinished"></translation>
+        <translation>Возвращённое фильтром изображение #%1 имеет %2 канал(а/ов)
+(должно быть не более 4)</translation>
     </message>
 </context>
 <context>
@@ -325,17 +354,17 @@
     <message>
         <location filename="../src/HeadlessProcessor.cpp" line="81"/>
         <source>At least a filter path or a filter command must be provided.</source>
-        <translation type="unfinished"></translation>
+        <translation>Должен быть предоставлен путь к фильтру или команда фильтра.</translation>
     </message>
     <message>
         <location filename="../src/HeadlessProcessor.cpp" line="83"/>
         <source>Custom command (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Пользовательская команда (%1)</translation>
     </message>
     <message>
         <location filename="../src/HeadlessProcessor.cpp" line="91"/>
         <source>Cannot find filter matching path %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Фильтр отсутствует на заданном пути %1</translation>
     </message>
     <message>
         <location filename="../src/HeadlessProcessor.cpp" line="98"/>
@@ -346,22 +375,28 @@
 Cannot retrieve default parameters.
 
 %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Ошибка при анализе параметров для фильтра:
+
+%1
+
+Не удалось восстановить значения по умолчанию.
+
+%2</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="112"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="116"/>
         <source>Error parsing supplied command: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Ошибка анализа данной команды: %1</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="115"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="119"/>
         <source>Supplied command (%1) does not match path (%2), (should be %3).</source>
-        <translation type="unfinished"></translation>
+        <translation>Данная команда (%1) не совпадает с путём (%2), (должно быть %3).</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="229"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="233"/>
         <source>Filter execution failed, but with no error message.</source>
-        <translation type="unfinished"></translation>
+        <translation>Применение фильтра не удалось, но без сообщения об ошибке.</translation>
     </message>
 </context>
 <context>
@@ -439,96 +474,110 @@ Cannot retrieve default parameters.
     <message>
         <location filename="../src/Widgets/InOutPanel.cpp" line="208"/>
         <source>Input</source>
-        <translation type="unfinished"></translation>
+        <translation>Ввод</translation>
     </message>
     <message>
         <location filename="../src/Widgets/InOutPanel.cpp" line="210"/>
         <source>Output</source>
-        <translation type="unfinished"></translation>
+        <translation>Вывод</translation>
     </message>
 </context>
 <context>
     <name>GmicQt::LanguageSelectionWidget</name>
     <message>
-        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="51"/>
+        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="53"/>
         <source>System default (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Системный (%1)</translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="62"/>
+        <source>Translations are very likely to be incomplete.</source>
+        <translation>Переводы в большинстве случаев неполны.</translation>
     </message>
 </context>
 <context>
     <name>GmicQt::MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="107"/>
+        <location filename="../src/MainWindow.cpp" line="109"/>
         <source>Add fave</source>
         <translation>Добавить в избранное</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="109"/>
+        <location filename="../src/MainWindow.cpp" line="111"/>
         <source>Reset parameters to default values</source>
-        <translation type="unfinished"></translation>
+        <translation>Сбросить параметры до значений по умолчанию</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="115"/>
+        <location filename="../src/MainWindow.cpp" line="117"/>
         <source>Copy G&apos;MIC command to clipboard</source>
         <translation>Скопируйте команду G&apos;MIC в буфер обмена</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="122"/>
+        <location filename="../src/MainWindow.cpp" line="124"/>
         <source>Rename fave</source>
-        <translation>Переименовать избранный</translation>
+        <translation>Переименовать избранное</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="124"/>
+        <location filename="../src/MainWindow.cpp" line="126"/>
         <source>Remove fave</source>
         <translation>Удалить из избранного</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="128"/>
+        <location filename="../src/MainWindow.cpp" line="130"/>
         <source>Expand/Collapse all</source>
         <translation>Свернуть/развернуть всё</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="130"/>
+        <location filename="../src/MainWindow.cpp" line="132"/>
         <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
         <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Университет Нормандии (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="137"/>
+        <location filename="../src/MainWindow.cpp" line="139"/>
         <source>Selection mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Режим выбора фильтров для скрытия из списка</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="175"/>
+        <location filename="../src/MainWindow.cpp" line="177"/>
         <source>Update filters</source>
         <translation>Обновить фильтры</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="343"/>
+        <location filename="../src/MainWindow.cpp" line="231"/>
+        <source>Manage visible tags
+(Right-click on a fave or a filter to set/remove tags)</source>
+        <translation>Управление видимыми маркерами
+(ПКМ на избранном/неизбранном фильтре, чтобы добавить/удалить маркеры)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="353"/>
         <source>Update completed</source>
         <translation>Обновление завершено</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="343"/>
-        <location filename="../src/MainWindow.cpp" line="345"/>
-        <location filename="../src/MainWindow.cpp" line="463"/>
+        <location filename="../src/MainWindow.cpp" line="353"/>
+        <location filename="../src/MainWindow.cpp" line="355"/>
+        <location filename="../src/MainWindow.cpp" line="475"/>
         <source>Filter definitions have been updated.</source>
         <translation>Определения фильтров обновлены.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="348"/>
+        <location filename="../src/MainWindow.cpp" line="358"/>
         <source>No download was needed.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="403"/>
-        <source>Plugin was called with a filter path with no matching filter:
-
-Path: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Загрузка не потребовалась.</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="411"/>
-        <location filename="../src/MainWindow.cpp" line="438"/>
+        <source>Plugin was called with a filter path with no matching filter:
+
+Path: %1</source>
+        <translation>Плагин был вызван путём к фильтру без соответствующего фильтра:
+
+Путь: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="419"/>
+        <location filename="../src/MainWindow.cpp" line="446"/>
         <source>Error parsing filter parameters definition for filter:
 
 %1
@@ -536,78 +585,92 @@ Path: %1</source>
 Cannot retrieve default parameters.
 
 %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Ошибка при анализе параметров для фильтра:
+
+%1
+
+Не удалось восстановить значения по умолчанию.
+
+%2</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="424"/>
+        <location filename="../src/MainWindow.cpp" line="432"/>
         <source>Plugin was called with a command that cannot be recognized as a filter:
 
 Command: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Плагин был вызван командой, которая не может быть распознана как фильтр:
+
+Команда: %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="419"/>
+        <location filename="../src/MainWindow.cpp" line="427"/>
         <source>Plugin was called with a command that cannot be parsed:
 
 %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Плагин был вызван командой, которая не может быть проанализирована:
+
+%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="428"/>
+        <location filename="../src/MainWindow.cpp" line="436"/>
         <source>Plugin was called with a command that does not match the provided path:
 
 Path: %1
 Command: %2
 Command found for this path : %3</source>
-        <translation type="unfinished"></translation>
+        <translation>Плагин был вызван командой, путь которой не совпадает с предоставленным:
+
+Путь: %1
+Команда: %2
+Команда, найденная по этому пути: %3</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="459"/>
+        <location filename="../src/MainWindow.cpp" line="471"/>
         <source>Filters update could not be achieved</source>
-        <translation type="unfinished"></translation>
+        <translation>Не удалось обновить</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="586"/>
+        <location filename="../src/MainWindow.cpp" line="597"/>
         <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
         <translation>Не удалось обновить&lt;br/&gt;по следующим причинам:&lt;br/&gt;</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="592"/>
+        <location filename="../src/MainWindow.cpp" line="603"/>
         <source>Update error</source>
         <translation>Ошибка обновления</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="792"/>
+        <location filename="../src/MainWindow.cpp" line="803"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="888"/>
+        <location filename="../src/MainWindow.cpp" line="899"/>
         <source>Waiting for cancelled jobs...</source>
-        <translation type="unfinished"></translation>
+        <translation>В ожидании отменённых заданий...</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1261"/>
+        <location filename="../src/MainWindow.cpp" line="1272"/>
         <source>Import faves</source>
         <translation>Импорт избранного</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1261"/>
+        <location filename="../src/MainWindow.cpp" line="1272"/>
         <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
         <translation>Вы хотите импортировать избранные из следующего файла?&lt;br/&gt;%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1264"/>
+        <location filename="../src/MainWindow.cpp" line="1275"/>
         <source>Don&apos;t ask again</source>
         <translation>Больше не спрашивать</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1376"/>
+        <location filename="../src/MainWindow.cpp" line="1387"/>
         <source>Confirmation</source>
         <translation>Подтвердить</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1376"/>
+        <location filename="../src/MainWindow.cpp" line="1387"/>
         <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
         <translation>Обрабатывается команда gmic.&lt;br&gt;Вы действительно хотите закрыть плагин?</translation>
     </message>
@@ -625,7 +688,7 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="49"/>
         <source>G&apos;MIC-Qt Plug-in progression</source>
-        <translation type="unfinished"></translation>
+        <translation>Прогресс плагина G&apos;MIC-Qt</translation>
     </message>
     <message>
         <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="52"/>
@@ -635,7 +698,7 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="150"/>
         <source>Updating filters...</source>
-        <translation type="unfinished"></translation>
+        <translation>Фильтры обновляются...</translation>
     </message>
     <message>
         <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="205"/>
@@ -654,7 +717,7 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="49"/>
         <source>G&apos;MIC-Qt Plug-in progression</source>
-        <translation type="unfinished"></translation>
+        <translation>Прогресс плагина G&apos;MIC-Qt</translation>
     </message>
     <message>
         <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="141"/>
@@ -682,35 +745,30 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Widgets/SearchFieldWidget.cpp" line="80"/>
         <source>Search in filters list (%1)</source>
-        <translation>Ищу в списке фильтиров (%1)</translation>
+        <translation>Поиск фильтра в списке (%1)</translation>
     </message>
 </context>
 <context>
     <name>GmicQt::Updater</name>
     <message>
-        <location filename="../src/Updater.cpp" line="196"/>
+        <location filename="../src/Updater.cpp" line="198"/>
         <source>Error downloading %1 (empty file?)</source>
-        <translation>Ошибка скачивания %1 (Пустой файл?)</translation>
+        <translation>Ошибка скачивания %1 (пустой файл?)</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="205"/>
+        <location filename="../src/Updater.cpp" line="207"/>
         <source>Could not read/decompress %1</source>
         <translation>Ошибка чтения/распаковки %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="211"/>
-        <source>Error creating file %1</source>
-        <translation>Ошибка создания файла %1</translation>
-    </message>
-    <message>
-        <location filename="../src/Updater.cpp" line="215"/>
+        <location filename="../src/Updater.cpp" line="212"/>
         <source>Error writing file %1</source>
         <translation>Ошибка записи файла %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="232"/>
+        <location filename="../src/Updater.cpp" line="229"/>
         <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
-        <translation type="unfinished"></translation>
+        <translation>Ошибка при загрузке %1&lt;br/&gt;Ошибка: %2: %3</translation>
     </message>
     <message>
         <location filename="../src/Updater.cpp" line="265"/>
@@ -718,27 +776,40 @@ Command found for this path : %3</source>
         <translation>Тайм-аут загрузки: %1</translation>
     </message>
 </context>
+<context>
+    <name>GmicQt::VisibleTagSelector</name>
+    <message>
+        <location filename="../src/Widgets/VisibleTagSelector.cpp" line="55"/>
+        <source>Show All Filters</source>
+        <translation>Отобразить все фильтры</translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/VisibleTagSelector.cpp" line="59"/>
+        <source>Show %1 Tags</source>
+        <translation>Отобразить %1 маркеры</translation>
+    </message>
+</context>
 <context>
     <name>GmicQt::ZoomLevelSelector</name>
     <message>
         <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="54"/>
         <source>Zoom in</source>
-        <translation type="unfinished"></translation>
+        <translation>Приблизить</translation>
     </message>
     <message>
         <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="55"/>
         <source>Zoom out</source>
-        <translation type="unfinished"></translation>
+        <translation>Отдалить</translation>
     </message>
     <message>
         <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="56"/>
         <source>Reset zoom</source>
-        <translation type="unfinished"></translation>
+        <translation>Сбросить масштабирование</translation>
     </message>
     <message>
         <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="156"/>
         <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
-        <translation type="unfinished"></translation>
+        <translation>Внимание: предпросмотр может быть неточным (изменена настройка для масштабирования)</translation>
     </message>
 </context>
 <context>
@@ -764,7 +835,7 @@ Command found for this path : %3</source>
     <message>
         <location filename="../ui/inoutpanel.ui" line="47"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>...</translation>
     </message>
     <message>
         <location filename="../ui/inoutpanel.ui" line="92"/>
@@ -782,38 +853,38 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="14"/>
         <source>Dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>Dialog</translation>
     </message>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="20"/>
         <location filename="../src/Host/None/JpegQualityDialog.cpp" line="12"/>
         <source>JPEG Quality</source>
-        <translation type="unfinished"></translation>
+        <translation>Качество JPEG</translation>
     </message>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="28"/>
         <source>0</source>
-        <translation type="unfinished"></translation>
+        <translation>0</translation>
     </message>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="42"/>
         <source>100</source>
-        <translation type="unfinished"></translation>
+        <translation>100</translation>
     </message>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="60"/>
         <source>Always use this quality for this execution of G&apos;MIC-Qt</source>
-        <translation type="unfinished"></translation>
+        <translation>Всегда использовать выбранное качество для G&apos;MIC-Qt</translation>
     </message>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="85"/>
         <source>&amp;Cancel</source>
-        <translation type="unfinished">&amp;Отмена</translation>
+        <translation>&amp;Отмена</translation>
     </message>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="92"/>
         <source>&amp;Ok</source>
-        <translation type="unfinished">&amp;Ok</translation>
+        <translation>&amp;Ok</translation>
     </message>
 </context>
 <context>
@@ -824,10 +895,15 @@ Command found for this path : %3</source>
         <translation>GMIC</translation>
     </message>
     <message>
-        <location filename="../ui/languageselectionwidget.ui" line="38"/>
+        <location filename="../ui/languageselectionwidget.ui" line="35"/>
         <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
         <translation>&lt;i&gt;(Требуется перезапуск)&lt;/i&gt;</translation>
     </message>
+    <message>
+        <location filename="../ui/languageselectionwidget.ui" line="48"/>
+        <source>Translate filters (WIP)</source>
+        <translation>Перевод фильтров (в процессе)</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -837,63 +913,63 @@ Command found for this path : %3</source>
         <translation>GMIC</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="165"/>
+        <location filename="../ui/mainwindow.ui" line="176"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Скачать определения фильтров с отдалённого ресурса&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Скачать определения фильтров из отдалённых ресурсов&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="168"/>
+        <location filename="../ui/mainwindow.ui" line="179"/>
         <source>Internet</source>
-        <translation>Internet</translation>
+        <translation>Интернет</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="500"/>
+        <location filename="../ui/mainwindow.ui" line="511"/>
         <source>TextLabel</source>
-        <translation type="unfinished">TextLabel</translation>
+        <translation>TextLabel</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="237"/>
-        <location filename="../ui/mainwindow.ui" line="244"/>
+        <location filename="../ui/mainwindow.ui" line="248"/>
+        <location filename="../ui/mainwindow.ui" line="255"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>...</translation>
     </message>
     <message>
         <location filename="../ui/mainwindow.ui" line="14"/>
         <source>MainWindow</source>
-        <translation type="unfinished">MainWindow</translation>
+        <translation>MainWindow</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="390"/>
+        <location filename="../ui/mainwindow.ui" line="401"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Включение/выключение предпросмотра&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(ПКМ на предпросмотре для мгновенного переключения)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="393"/>
+        <location filename="../ui/mainwindow.ui" line="404"/>
         <source>Preview</source>
         <translation>Предпросмотр</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="484"/>
+        <location filename="../ui/mainwindow.ui" line="495"/>
         <source>Settings...</source>
         <translation>Настройки...</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="513"/>
+        <location filename="../ui/mainwindow.ui" line="524"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Отмена</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="526"/>
+        <location filename="../ui/mainwindow.ui" line="537"/>
         <source>&amp;Fullscreen</source>
         <translation>&amp;Полный экран</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="539"/>
+        <location filename="../ui/mainwindow.ui" line="550"/>
         <source>&amp;Apply</source>
         <translation>&amp;Применить</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="552"/>
+        <location filename="../ui/mainwindow.ui" line="563"/>
         <source>&amp;OK</source>
         <translation>&amp;Ok</translation>
     </message>
@@ -963,27 +1039,77 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Host/None/host_none.cpp" line="80"/>
         <source>Could not open file.</source>
-        <translation type="unfinished"></translation>
+        <translation>Не удалось открыть файл.</translation>
     </message>
     <message>
         <location filename="../src/Host/None/host_none.cpp" line="84"/>
         <source>Default image</source>
-        <translation type="unfinished"></translation>
+        <translation>Изображение по умолчанию</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="91"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="81"/>
         <source>Visible</source>
-        <translation type="unfinished"></translation>
+        <translation>Видимость</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="94"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="103"/>
         <source>Available filters (%1)</source>
         <translation>Доступные фильтры (%1)</translation>
     </message>
     <message>
         <location filename="../src/Misc.cpp" line="330"/>
         <source>List %1 cannot be merged considering theses runs: %2</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Список %1 не может быть объединён, учитывая это: %2</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="151"/>
+        <source>%1 Tag</source>
+        <translation>%1 маркер</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="157"/>
+        <source>None</source>
+        <translation>Нет</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="158"/>
+        <source>Red</source>
+        <translation>Красный</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="159"/>
+        <source>Green</source>
+        <translation>Зелёный</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="160"/>
+        <source>Blue</source>
+        <translation>Синий</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="161"/>
+        <source>Cyan</source>
+        <translation>Голубой</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="162"/>
+        <source>Magenta</source>
+        <translation>Пурпурный</translation>
+    </message>
+    <message>
+        <location filename="../src/Tags.cpp" line="163"/>
+        <source>Yellow</source>
+        <translation>Жёлтый</translation>
+    </message>
+    <message>
+        <location filename="../src/LanguageSettings.cpp" line="127"/>
+        <source>Could not install translator for file %1</source>
+        <translation>Не удалось установить переводчик для файла %1</translation>
+    </message>
+    <message>
+        <location filename="../src/LanguageSettings.cpp" line="130"/>
+        <source>Could not load translation file %1</source>
+        <translation>Не удалось загрузить файл перевода %1</translation>
     </message>
 </context>
 <context>
@@ -1007,27 +1133,27 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Host/None/ImageDialog.cpp" line="71"/>
         <source>G&apos;MIC-Qt filter output</source>
-        <translation type="unfinished"></translation>
+        <translation>G&apos;MIC-Qt результат работы фильтра</translation>
     </message>
     <message>
         <location filename="../src/Host/None/ImageDialog.cpp" line="82"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Закрыть</translation>
     </message>
     <message>
         <location filename="../src/Host/None/ImageDialog.cpp" line="85"/>
         <source>Save as...</source>
-        <translation type="unfinished"></translation>
+        <translation>Сохранить как...</translation>
     </message>
     <message>
         <location filename="../src/Host/None/ImageDialog.cpp" line="120"/>
         <source>%1 file (*.%2)</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 файл (*.%2)</translation>
     </message>
     <message>
         <location filename="../src/Host/None/ImageDialog.cpp" line="141"/>
         <source>Save image as...</source>
-        <translation type="unfinished"></translation>
+        <translation>Сохранить изображение как...</translation>
     </message>
 </context>
 <context>
@@ -1035,12 +1161,12 @@ Command found for this path : %3</source>
     <message>
         <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
         <source>Error</source>
-        <translation type="unfinished">Ошибка</translation>
+        <translation>Ошибка</translation>
     </message>
     <message>
         <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
         <source>Could not write image file %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Не удалось записать изображение в файл %1</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
